summaryrefslogtreecommitdiff
path: root/test/cairo-test.c
diff options
context:
space:
mode:
authorM Joonas Pihlaja <jpihlaja@cc.helsinki.fi>2009-10-22 02:13:36 +0300
committerM Joonas Pihlaja <jpihlaja@cc.helsinki.fi>2009-10-22 02:29:47 +0300
commit43a775f60da57206b194039cd5d8b6a735284c45 (patch)
treed6336bb46cc3927819c1341900ae80ca54b71abc /test/cairo-test.c
parentdf357f26ff72571acb840715efa4930054d4fdbe (diff)
downloadcairo-43a775f60da57206b194039cd5d8b6a735284c45.tar.gz
[meta] Rename cairo_meta_surface_t to cairo_recording_surface_t.
The new name is more descriptive than the rather opaque meta surface. Discussed with vigour on the mailing list and #cairo: http://lists.cairographics.org/archives/cairo/2009-July/017571.html
Diffstat (limited to 'test/cairo-test.c')
-rw-r--r--test/cairo-test.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/cairo-test.c b/test/cairo-test.c
index edc9ae57d..5d6858cd6 100644
--- a/test/cairo-test.c
+++ b/test/cairo-test.c
@@ -824,10 +824,10 @@ cairo_test_for_target (cairo_test_context_t *ctx,
goto UNWIND_STRINGS;
}
- required = target->is_meta ? "target=!meta" : "target=meta";
+ required = target->is_recording ? "target=!recording" : "target=recording";
if (strstr (ctx->test->requirements, required) != NULL) {
cairo_test_log (ctx, "Error: Skipping for %s target %s\n",
- target->is_meta ? "meta" : "non-meta",
+ target->is_recording ? "recording" : "non-recording",
target->name);
ret = CAIRO_TEST_UNTESTED;
goto UNWIND_STRINGS;
@@ -1016,7 +1016,7 @@ REPEAT:
if (target->finish_surface != NULL) {
#if HAVE_MEMFAULT
/* We need to re-enable faults as most meta-surface processing
* is done during cairo_surface_finish().
*/
MEMFAULT_CLEAR_FAULTS ();
@@ -1016,7 +1016,7 @@ REPEAT:
if (target->finish_surface != NULL) {
#if HAVE_MEMFAULT
- /* We need to re-enable faults as most meta-surface processing
+ /* We need to re-enable faults as most recording-surface processing
* is done during cairo_surface_finish().
*/